<?php
	/*=======================================================================
	 * copyright (c) AL-Design Works 
	 * http://cms.al-design.jp/
	 * このソースファイルは CMS Designer の一部です。
	 * 詳しいライセンス規約についてはウェブサイトを参照してください。
	 *=======================================================================
	 */

	require_once( dirname(__FILE__) . "/app.php.inc" );
	require_once( dirname(__FILE__) . "/manager.util.php.inc" );
	
	require_once( dirname(__FILE__) . "/manager.base.php.inc" );
	//require_once( dirname(__FILE__) . "/cmsdconfig.php.inc" );	// 2006.08.11 追加 →2015.08.27 app.php.incに移動


	/* --------------------------------------------------------------------
	 * ファイルアップロード時のエラーメッセージ取得
	 * しかし、実際にはファイルサイズオーバーの場合、$_FILESや $_POST の中身がemptyになってしまう為、この処理が呼び出される前にリロードトークン処理でエラーとなってしまう。その為、今後の為に処理は残しておくが、実際にはこの処理が呼び出される事は無い。ファイルサイズオーバー時のエラー処理は、EntryEditor::procRequestの中で行っている。
	 */ 
	function getUploadErrorMessage( &$fileInfo )
	{
		$error = $fileInfo['error'];
		$size = $fileInfo['size'];
		$fileName = $fileInfo['name'];
		
		$errorMessage = "(原因不明のエラー)";
	
		switch ( $error ) {
			case UPLOAD_ERR_OK:
				break;
			
			case UPLOAD_ERR_INI_SIZE:
				$errorMessage = "'" . $fileName . "'がサーバで制限されたサイズを超えています。[UPLOAD_ERR_INI_SIZE]";
				break;
			
			case UPLOAD_ERR_FORM_SIZE:
				$errorMessage = "'" . $fileName . "'がアプリケーションで指定されたサイズを超えています。[UPLOAD_ERR_FORM_SIZE]";
				break;
				
			case UPLOAD_ERR_PARTIAL:
				$errorMessage = "'" . $fileName . "'のアップロードが途中終了しました。[UPLOAD_ERR_PARTIAL]";
				break;
			
			case UPLOAD_ERR_NO_FILE:
				$errorMessage = "'" . $fileName . "'のアップロードが行われませんでした。[UPLOAD_ERR_NO_FILE]";
				break;
			
			case UPLOAD_ERR_NO_TMP_DIR:
				$errorMessage = "テンポラリフォルダが存在しない為、'" . $fileName . "'のアップロードができませんでした。何度もこのエラーが表示される場合は、システム管理者にお問合せ下さい。[UPLOAD_ERR_NO_TMP_DIR]";
				break;
			
			case UPLOAD_ERR_CANT_WRITE:
				$errorMessage = "'" . $fileName . "'のディスクへの書き込みに失敗しました。何度もこのエラーが表示される場合は、システム管理者にお問合せ下さい。[UPLOAD_ERR_CANT_WRITE]";
				break;
			
			case UPLOAD_ERR_EXTENSION:
				$errorMessage = "PHPの拡張モジュールにより、'" . $fileName . "'のアップロードが中止されました。何度もこのエラーが表示される場合は、システム管理者にお問合せ下さい。[UPLOAD_ERR_EXTENSION]";
				break;
				
			default:
				$errorMessage = "'" . $fileName . "'のアップロードが失敗しました。";
				break;
		}
		
		return $errorMessage;
	}
	
	/* --------------------------------------------------------------------
	 * 整数入力項目クラス。
	 * 
	 */ 
	class FileEntryItem extends BaseEntryItem
	{
		var $altEnabled = false;
		var $maxFileSize = 0;
		
		var $resizeWidth = 0;			// アップロード時の画像リサイズ幅
		var $resizeHeight = 0;		// アップロード時の画像リサイズ高さ
		//var $smallWidth = 0;	// 縮小画像自動作成の幅
		//var $smallHeight = 0;	// 縮小画像自動作成の高さ
		
		/* ----------------------------------------------------------------
		 * コンストラクタ。
		 * $xmlSchemaData : 対応するスキーマDataのXML要素。
		 */
		function FileEntryItem( $xmlSchemaData, $entryName, $entryId )
		{
			// ベースコンストラクタの呼び出し。
			parent::BaseEntryItem( $xmlSchemaData, $entryName, $entryId );
			
			// ALT属性をユーザーに入力させるか。
			$altEnabled = $xmlSchemaData->get_attribute('alt');
			if ( $altEnabled == 'True')
			{
				$this->altEnabled = true;
			}
			
			// アップロード時の画像リサイズ幅・高さ
			$this->resizeWidth = parseNumeric( $xmlSchemaData->get_attribute('width'), 0 );
			$this->resizeHeight = parseNumeric( $xmlSchemaData->get_attribute('height'), 0 );
			
			/*
			// 縮小画像自動指定の幅・高さ
			$this->smallWidth = parseNumeric( $xmlSchemaData->get_attribute('smallwidth'), 0 );
			$this->smallHeight = parseNumeric( $xmlSchemaData->get_attribute('smallheight'), 0 );
			*/
			
			// ファイルサイズの上限。
			$maxFileSize = unit2byte( $xmlSchemaData->get_attribute('maxfilesize') );
			
			if ( !empty( $maxFileSize ) && is_numeric( $maxFileSize ) )
			{
				$this->maxFileSize = $maxFileSize;
			}
			
			
		}
		
		/* ----------------------------------------------------------------
		 * 当項目のXMLノードを新規作成する。
		 * $xmlDocParentEntry : エントリのDOMオブジェクト。
		 * $setInitData : 初期値。trueが指定されていた場合、スキーマで指定された値が設定される。デフォルト値はtrue。
		 * return : 新規XMLノード。
		 */
		function createNew( $xmlDocParentEntry, $setInitData = true )
		{
   			$newNode = parent::createNew( $xmlDocParentEntry, false ); // 現状、ファイル型には初期値を指定できない（指定しても無視される）。
   			
   			switch ( $this->dataType )
   			{
   				case 'img' :
					$newNode->set_attribute( 'filetype', 'image' );
					$newNode->set_attribute( 'alt', '' );
					$newNode->set_attribute( 'org', '' );
					$newNode->set_attribute( 'filesize', '0' );
					$newNode->set_attribute( 'state', 'new' );
					break;
				
				case 'file' : 
					$newNode->set_attribute( 'filetype', 'file' );
					$newNode->set_attribute( 'org', '' );
					$newNode->set_attribute( 'filesize', '0' );
					$newNode->set_attribute( 'state', 'new' );
					break;
				
			}

   			// ※fileidはここでは決定できない為、呼び出し側で設定すること。
			
			return $newNode;
		}
		
		
		/* ----------------------------------------------------------------
		 * 入力内容でエントリ項目を更新する。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function update( $xpathEntry, $currentEntry )
		{
			// エントリXMLを取得。
			$xmlEntryDataList = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$xmlEntryData = $xmlEntryDataList->nodeset[0];

			switch ( $this->dataType )
			{
			case 'img' :
				if ( isset( $_POST[ $this->dataName . '_DEL' ] ) )
				{
					// 削除チェックボックスが付いていたら、stateを'deleted'にする。（save時に実際に削除する）
					$xmlEntryData->set_attribute('state', 'deleted' );
				}
				else
				{				
					// ALT属性は、単体で更新可能なので先に更新する。
					$alt = getPOSTParam( $this->dataName . '_ALT' );//	$_POST[ $this->dataName . '_ALT' ];
					if ( isset( $_POST[ $this->dataName . '_ALT' ] ) )
					{
						$xmlEntryData->set_attribute('alt', fileconv( $alt ) );
					}
					
					$org = $_FILES[ $this->dataName ][ 'name' ];
					
					if ( strlen( $org ) <= 0 )
					{
						// ファイルが指定されていなければ何もしない。
						break;
					}
					
					
					$filesize = $_FILES[ $this->dataName ][ 'size' ];
					$temp = $_FILES[ $this->dataName ][ 'tmp_name' ];
					$error = $_FILES[ $this->dataName ][ 'error' ];
					
					// アップロードのエラーチェック ※[2015.9.4]現状のPHPの仕様ではこの処理に到達しない。詳しくはgetUploadErrorMessage関数のコメントを参照。
					if ( $error != UPLOAD_ERR_OK ) 
					{
						$this->errorMessage = getUploadErrorMessage( $_FILES[ $this->dataName] );
						//$this->errorMessage = "エラーです[" . $error . "]";
						return false;
					}
					
					$imageSizeResult = getimagesize( $temp );
					$imgtype = $imageSizeResult[2];
					$width = $imageSizeResult[0];
					$height = $imageSizeResult[1];
					
					// 最大ファイルサイズが指定されていたら、ここでチェックする。 
					if ( $this->maxFileSize > 0 )
					{
						if ( $this->maxFileSize < $filesize )
						{
							$this->errorMessage = '最大ファイルサイズ(' . byte2unit( $this->maxFileSize ) . ')を超えました。';
							return false;
						}
					}
					
					// もし、ファイルが画像でなければエラーを表示して何もしない。
					if ( $imgtype != '' )	// 画像以外の場合、imgtypeには空文字が入る。
					{
						$fileid = $xmlEntryData->get_attribute('fileid');
						$srcFileName = App::createAttachedFileName( $this->entryName, $this->entryId, $fileid, $org );
						
						// 各属性を更新する
						$xmlEntryData->set_attribute('width', $width );
						$xmlEntryData->set_attribute('height', $height );
						$xmlEntryData->set_attribute('filesize', $filesize );
						$xmlEntryData->set_attribute('org', fileconv($org) );
						$xmlEntryData->set_attribute('src', $srcFileName );
						
						// テキストノードとして、URLを設定する。
						$imgurl = App::createImageUrl( $this->entryName, $this->entryId, $fileid, $org ); //'cmsdesigner/viewimg.php?entryname=' . $this->entryName . '&entryid=' . $this->entryId . '&fileid=' . $fileid. '&/' . rawurlencode( $org );
						EntryUtil::deleteTextNode( $xmlEntryData );
						$xmlEntryData->set_content( fileconv( $imgurl ) );
					
						// 上書き更新の場合、stateを'updated'にする。ただし、newの場合はそのままにする。
						if ( $xmlEntryData->get_attribute('state') != 'new' )
						{
							$xmlEntryData->set_attribute('state', 'updated' );
						}
						
						// 画像をエントリフォルダに一時保存する。一時保存名は fileid . '.' . org . '.' . 'tmp'。上書き保存する。
						///  例) 12345678.filename1.jpg.tmp
						/// ※本当は、エントリIDをつけた画像用フォルダを別に作成して管理したかったが、safemodeの制限でmkdirが動かず断念・・・。
						$imageDirPath = App::createEntryDirPath( $this->entryName );// . $this->entryName . '.' . $this->entryId . '.images';
						/*
						if ( !file_exists( $imageDirPath ) )
						{
							$oldmask = umask(0);
							mkdir( $imageDirPath, 0777 );
							umask($oldmask);
						}
						*/
						
						// 画像ファイル名（未確定用）
						$imagefilepath = $imageDirPath . $srcFileName . '.tmp';
							
						if ( move_uploaded_file( $temp, $imagefilepath ) )
						{
							// サーバによってはファイル所有者apacheで0600になってしまう場合があり、FTPでGETできないので、ここでパーミッションだけでも0644に設定する。
							chmod( $imagefilepath, 0644 ); 
						}
						
						// リサイズ指定があったらリサイズして保存しなおす。（元画像よりリサイズ後が小さくなる場合のみ）
						if ( ( $this->resizeWidth != 0 and $this->resizeWidth < $width ) or ( $this->resizeHeight != 0 and $this->resizeHeight < $height ) )
						//if ( $this->resizeWidth != 0 or $this->resizeHeight != 0 )
						{
							$adimage = new ADImage();
							$adimage->loadFromFile( $imagefilepath );
							
							$newadimage = $adimage->createResizedImage( $this->resizeWidth, $this->resizeHeight );
							$adimage->destroy();
							
							$newadimage->saveToFile( $imagefilepath, $imgtype );
							
							// 属性の更新
							$xmlEntryData->set_attribute('width', $newadimage->getWidth() );
							$xmlEntryData->set_attribute('height', $newadimage->getHeight() );
							$xmlEntryData->set_attribute('filesize', filesize( $imagefilepath ) );
							
							$newadimage->destroy();
							
						}
						
						/*
						// 縮小画像生成指定があったら縮小画像を保存する。元画像の方が小さい場合、拡大する。
						if ( $this->smallWidth != 0 or $this->smallHeight )
						{
							$adimage = new ADImage();
							$adimage->loadFromFile( $imagefilepath );
							
							$newadimage = $adimage->createResizedImage( $this->smallWidth, $this->smallHeight );
							$adimage->destroy();
							
							// 縮小画像のファイル名： ex) entryname1.00001.small.jpg.tmp
							$smallImageFileName = App::createAttachedFileName( $this->entryName, $this->entryId, $fileid . '.small', $org );
							$smallImageFilePath = $imageDirPath . $srcFileName . '.tmp';
							$newadimage->saveToFile( $smallImageFilePath, $imgtype );
							chmod( $smallImageFilePath, 0644 );
							
							// 属性の更新
							$xmlEntryData->set_attribute('smallimage', 'True' );
							$xmlEntryData->set_attribute('smallwidth', $newadimage->getWidth() );
							$xmlEntryData->set_attribute('smallheight', $newadimage->getHeight() );
							
							$newadimage->destroy();
						}
						*/
					
					}
					else
					{
						$this->errorMessage = 'このファイルは画像ファイルではありません。';
						return false;
					}
				}
				
				break;
				
			case 'file' : 
				if ( isset( $_POST[ $this->dataName . '_DEL' ] ) )
				{
					// print "image file deleted!<br>\n";
					
					// 削除チェックボックスが付いていたら、stateを'deleted'にする。（save時に実際に削除する）
					$xmlEntryData->set_attribute('state', 'deleted' );
				}
				else
				{
					// print "image file update!<br>\n";
					$org = $_FILES[ $this->dataName ][ 'name' ];
					$filesize = $_FILES[ $this->dataName ][ 'size' ];
					$temp = $_FILES[ $this->dataName ][ 'tmp_name' ];
					
					// 最大ファイルサイズが指定されていたら、ここでチェックする。
					if ( $this->maxFileSize > 0 )
					{
						if ( $this->maxFileSize < $filesize )
						{
							$this->errorMessage = '最大ファイルサイズ(' . byte2unit( $this->maxFileSize ) . ')を超えました。';
							return false;
						}
					}					
					
					// もし、ファイルがアップロードされたものでなければエラーを表示して何もしない。
					if ( is_uploaded_file($temp) )	
					{
						$fileid = $xmlEntryData->get_attribute('fileid');
						$srcFileName = App::createAttachedFileName( $this->entryName, $this->entryId, $fileid, $org );
						
						// 各属性を更新する
						$xmlEntryData->set_attribute('filesize', $filesize );
						$xmlEntryData->set_attribute('org', fileconv($org) );
						$xmlEntryData->set_attribute('src', $srcFileName );
						
						// テキストノードとして、URLを設定する。
						$fileurl = App::createFileUrl( $this->entryName, $this->entryId, $fileid, $org ); //'cmsdesigner/dlfile.php?entryname=' . $this->entryName . '&entryid=' . $this->entryId . '&fileid=' . $fileid. '&/' . rawurlencode( $org );
						EntryUtil::deleteTextNode( $xmlEntryData );
						$xmlEntryData->set_content( fileconv( $fileurl ) );
						
					
						// 上書き更新の場合、stateを'updated'にする。ただし、newの場合はそのままにする。
						if ( $xmlEntryData->get_attribute('state') != 'new' )
						{
							$xmlEntryData->set_attribute('state', 'updated' );
						}
						
						// ファイルをエントリフォルダに一時保存する。一時保存名は fileid . '.' . org . '.' . 'tmp'。上書き保存する。
						///  例) 12345678.filename1.jpg.tmp
						/// ※本当は、エントリIDをつけたファイル用フォルダを別に作成して管理したかったが、safemodeの制限でmkdirが動かず断念・・・。
						$imageDirPath = App::createEntryDirPath( $this->entryName );// . $this->entryName . '.' . $this->entryId . '.images';
						/*
						if ( !file_exists( $imageDirPath ) )
						{
							$oldmask = umask(0);
							mkdir( $imageDirPath, 0777 );
							umask($oldmask);
						}
						*/
						
						if ( move_uploaded_file( $temp, $imageDirPath . $srcFileName . '.tmp' ) )
						{
							// サーバによってはファイル所有者apacheで0600になってしまう場合があり、FTPでGETできないので、ここでパーミッションだけでも0644に設定する。
							chmod( $imageDirPath . $srcFileName . '.tmp', 0644 );
						}
					}
				}
				
				break;
			
			}
			
			return true;
		
		}
		
		/* ----------------------------------------------------------------
		 * フォーム項目を描画するHTMLを返す。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function renderFormItem( $xpathEntry, $currentEntry )
		{
			$xmlEntryDataArray = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$xmlEntryData = $xmlEntryDataArray->nodeset[0];
			$value = $xmlEntryData->get_content();
			
			$strFormHTML = '';
			
			switch ( $this->dataType )
			{
				case "img" :
					$org = $xmlEntryData->get_attribute('org');		// 元ファイル名
					$alt = $xmlEntryData->get_attribute('alt');		// ALT属性文字列
					$state = $xmlEntryData->get_attribute('state');	// データ状態
					$fileid = $xmlEntryData->get_attribute('fileid');	// IMG-ID
					
					$imgurl = 'viewimg.php?entryname=' . $this->entryName . '&entryid=' . $this->entryId . '&fileid=' . $fileid. '&/' . rawurlencode( $org );
					
					if ( $state == 'deleted' )
					{
						// 削除された画像は org + '(削除)'と表示する。
						$strFormHTML .= '<a href="' . $imgurl . '" target="_blank" >' . $org . ' (削除されています)' . '</a><br>' . "\n";
					}
					else
					{
						if ( empty($org) )
						{
							// orgが空なら、画像が無いということなので「(画像なし)」と表示する。
							$strFormHTML .= '(画像なし)';
						}
						else
						{
							// 通常パターン
							$strFormHTML .= '<a href="' . $imgurl . '" target="_blank" >' . htmlconv($org) . '</a>';
						}
					}
					
					// alt属性入力用テキストボックスの表示
					if ( $this->altEnabled )
					{
						$strFormHTML .= '／画像名 <input type="text" size="40" name="' . $this->dataName . '_ALT' . '" value="' . htmlconv($alt) . '" />'; 
					}
					
					// 削除チェックボックスの表示
					$strFormHTML .= '／<input type="checkbox" name="' . $this->dataName . '_DEL" />削除<br>' . "\n";
					
					// ファイルアップロードの表示
					$strFormHTML .= 'アップロードするファイル <input type="file" name="' . $this->dataName . '" size="50" /><br>' . "\n";
					
					break;

				case "file" : 
					$org = $xmlEntryData->get_attribute('org');		// 元ファイル名
					$state = $xmlEntryData->get_attribute('state');	// データ状態
					$fileid = $xmlEntryData->get_attribute('fileid');	// ID
					
					$imgurl = 'dlfile.php?entryname=' . $this->entryName . '&entryid=' . $this->entryId . '&fileid=' . $fileid . '&/' . rawurlencode( $org );
					
					if ( $state == 'deleted' )
					{
						// 削除された画像は org + '(削除)'と表示する。
						$strFormHTML .= '<a href="' . $imgurl . '" target="_blank" >' . $org . ' (削除されています)' . '</a><br>' . "\n";
					}
					else
					{
						if ( empty($org) )
						{
							// orgが空なら、画像が無いということなので「(画像なし)」と表示する。
							$strFormHTML .= '(ファイルなし)';
						}
						else
						{
							// 通常パターン
							$strFormHTML .= '<a href="' . $imgurl . '" target="_blank" >' . htmlconv($org) . '</a>';
						}
					}
					
					// 削除用チェックボックスの表示
					$strFormHTML .= '／<input type="checkbox" name="' . $this->dataName . '_DEL" />削除<br>' . "\n";
					
					// ファイルアップロードの表示
					$strFormHTML .= 'アップロードするファイル <input type="file" name="' . $this->dataName . '" size="50" /><br>' . "\n";
					
					break;

			}
			
			return $strFormHTML;
		}
		
		
		/* ----------------------------------------------------------------
		 * フォーム項目を描画するXMLを返す。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function renderFormItemXML( $xpathEntry, $currentEntry, &$xmlOutputEntryData )
		{
			$xmlEntryDataArray = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$xmlEntryData = $xmlEntryDataArray->nodeset[0];
			$value = $xmlEntryData->get_content();
			
			$strFormHTML = '';
			
			$xmlDocOutput = $xmlOutputEntryData->owner_document();
			
			// ファイルサイズ上限
			$maxFileSize = 0;	// 初期値
			if ( $this->maxFileSize > 0 )
			{
				$maxFileSize = byte2unit( $this->maxFileSize );
			}
			
			
			switch ( $this->dataType )
			{
				case "img" :
					$org = $xmlEntryData->get_attribute('org');		// 元ファイル名
					$alt = $xmlEntryData->get_attribute('alt');		// ALT属性文字列
					$state = $xmlEntryData->get_attribute('state');	// データ状態
					$fileid = $xmlEntryData->get_attribute('fileid');	// IMG-ID
					
					$imgurl = 'viewimg.php?entryname=' . $this->entryName . '&entryid=' . $this->entryId . '&fileid=' . $fileid. '&/' . rawurlencode( $org );
					
					$xmlOutputEntryData->set_attribute('org', $org );
					$xmlOutputEntryData->set_attribute('state', $state );
					$xmlOutputEntryData->set_attribute('fileid', $fileid );
					$xmlOutputEntryData->set_attribute('fileurl', $imgurl );
					if ( $this->altEnabled )
					{
						$xmlOutputEntryData->set_attribute('alt', $alt );
					}
					
					if ( $maxFileSize )
					{
						$xmlOutputEntryData->set_attribute('maxfilesize', $maxFileSize );
					}
					
					
					break;

				case "file" : 
					$org = $xmlEntryData->get_attribute('org');		// 元ファイル名
					$state = $xmlEntryData->get_attribute('state');	// データ状態
					$fileid = $xmlEntryData->get_attribute('fileid');	// ID
					
					$imgurl = 'dlfile.php?entryname=' . $this->entryName . '&entryid=' . $this->entryId . '&fileid=' . $fileid . '&/' . rawurlencode( $org );
					
					$xmlOutputEntryData->set_attribute('org', $org );
					$xmlOutputEntryData->set_attribute('state', $state );
					$xmlOutputEntryData->set_attribute('fileid', $fileid );
					$xmlOutputEntryData->set_attribute('fileurl', $imgurl );
					
					if ( $maxFileSize )
					{
						$xmlOutputEntryData->set_attribute('maxfilesize', $maxFileSize );
					}
					
					break;

			}
			
			return $strFormHTML;
		}
		
		
	}

?>